.. _ecad_functions_api:

ECA&D indices
=============

icclim 5.2 comes with convenience functions to call each individual index from `icclim` namespace.
These functions are autogenerated and are stored in `_generated_api.py`.
Additionally, user custom indices can be called with the `icclim.custom_index`.

For example to use this new API with the index `su` you can do:

.. code-block:: python

    import glob
    import icclim

    summer_days = icclim.su(in_files=glob.glob("netcdf_files/tasmax*.nc"))

Generated API
-------------

.. automodule:: icclim._generated_api
    :members:

    .. rubric:: Functions

    .. autosummary::
        .. Documentation below is auto-generated with the extract-icclim-funs.py script
        .. Generated API comment:Begin

        tg
        tn
        tx
        dtr
        etr
        vdtr
        su
        tr
        wsdi
        tg90p
        tn90p
        tx90p
        txx
        tnx
        csu
        gd4
        fd
        cfd
        hd17
        id
        tg10p
        tn10p
        tx10p
        txn
        tnn
        csdi
        cdd
        prcptot
        rr1
        sdii
        cwd
        rr
        r10mm
        r20mm
        rx1day
        rx5day
        r75p
        r75ptot
        r95p
        r95ptot
        r99p
        r99ptot
        sd
        sd1
        sd5cm
        sd50cm
        cd
        cw
        wd
        ww
        fxx
        fg6bft
        fgcalm
        fg
        ddnorth
        ddeast
        ddsouth
        ddwest
        gsl
        spi6
        spi3
        custom_index

        .. Generated API comment:End
